@@ -170,7 +170,7 @@ impl From<Option<GitReference>> for GitCheckout {
 }
 
 impl fmt::Display for GitCheckout {
-    fn fmt(&self, f: &mut fmt::Formatter) -> fmt::Result {
+    fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
         match self {
             Self::DefaultBranch => write!(f, ""),
             Self::Branch(s) | Self::Rev(s) | Self::Tag(s) => write!(f, "@{}", s),
@@ -193,7 +193,7 @@ impl GitCheckout {
 }
 
 impl fmt::Display for Source {
-    fn fmt(&self, f: &mut fmt::Formatter) -> fmt::Result {
+    fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
         match self {
             Self::Git { url, reference } => {
                 let checkout: GitCheckout = reference.clone().into();
@@ -553,7 +553,8 @@ impl Config {
         }
 
         let matches = &matches.as_ref().unwrap_or_else(|| shell.default_matches());
-        let apply = &apply.as_ref().unwrap_or_else(|| Shell::default_apply());
+        #[allow(clippy::redundant_closure)]
+        let apply = apply.as_ref().unwrap_or_else(|| Shell::default_apply());
         let count = map.len();
         let mut errors = Vec::new();
 
